summaryrefslogtreecommitdiffstats
path: root/twin/tabbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'twin/tabbox.cpp')
-rw-r--r--twin/tabbox.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/twin/tabbox.cpp b/twin/tabbox.cpp
index d88146f22..feca2d77d 100644
--- a/twin/tabbox.cpp
+++ b/twin/tabbox.cpp
@@ -53,7 +53,7 @@ TabBox::TabBox( Workspace *ws, const char *name )
m = DesktopMode; // init variables
reconfigure();
reset();
- connect(&delayedShowTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(show()));
+ connect(&delayedShowTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(show()));
XSetWindowAttributes attr;
attr.override_redirect = 1;
@@ -474,7 +474,7 @@ void TabBox::drawContents( TQPainter * )
p.setPen(colorGroup().text());
p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
- Qt::AlignLeft | Qt::AlignVCenter | TQt::SingleLine, s);
+ TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, s);
y += lineHeight;
}
@@ -521,7 +521,7 @@ void TabBox::drawContents( TQPainter * )
// draw desktop-number
p.setFont(f);
TQString num = TQString::number(iDesktop);
- p.drawText(x+5, y+2, iconWidth, iconHeight, Qt::AlignCenter, num);
+ p.drawText(x+5, y+2, iconWidth, iconHeight, TQt::AlignCenter, num);
p.restore();
@@ -532,7 +532,7 @@ void TabBox::drawContents( TQPainter * )
p.setPen(colorGroup().text());
p.drawText(x+5 + iconWidth + 8, y, r.width() - 5 - iconWidth - 8, lineHeight,
- Qt::AlignLeft | Qt::AlignVCenter | TQt::SingleLine,
+ TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine,
workspace()->desktopName(iDesktop));
// show mini icons from that desktop aligned to each other
@@ -708,7 +708,7 @@ void TabBox::delayedShow()
void TabBox::handleMouseEvent( XEvent* e )
{
- XAllowEvents( tqt_xdisplay(), AsyncPointer, GET_QT_X_TIME() );
+ XAllowEvents( tqt_xdisplay(), AsyncPointer, get_tqt_x_time() );
if( e->type != ButtonPress )
return;
TQPoint pos( e->xbutton.x_root, e->xbutton.y_root );
@@ -866,7 +866,7 @@ void Workspace::slotWalkThroughWindows()
return;
if ( options->altTabStyle == Options::CDE || !options->focusPolicyIsReasonable())
{
//XUngrabKeyboard(tqt_xdisplay(), GET_QT_X_TIME()); // need that because of accelerator raw mode
// CDE style raise / lower
CDEWalkThroughWindows( true );
}
@@ -1180,7 +1180,7 @@ void Workspace::tabBoxKeyPress( const KKeyNative& keyX )
if (control_grab || tab_grab)
{
uint keyQt = keyX.keyCodeQt();
- if ( ((keyQt & 0xffff) == Qt::Key_Escape)
+ if ( ((keyQt & 0xffff) == TQt::Key_Escape)
&& !(forward || backward) )
{ // if Escape is part of the shortcut, don't cancel
closeTabBox();
@@ -1360,7 +1360,7 @@ Client* Workspace::previousStaticClient( Client* c ) const
bool Workspace::establishTabBoxGrab()
{
if( XGrabKeyboard( tqt_xdisplay(), root, FALSE,
- GrabModeAsync, GrabModeAsync, GET_QT_X_TIME()) != GrabSuccess )
+ GrabModeAsync, GrabModeAsync, get_tqt_x_time()) != GrabSuccess )
return false;
// Don't try to establish a global mouse grab using XGrabPointer, as that would prevent
// using Alt+Tab while DND (#44972). However force passive grabs on all windows
@@ -1376,7 +1376,7 @@ bool Workspace::establishTabBoxGrab()
void Workspace::removeTabBoxGrab()
{
- XUngrabKeyboard(tqt_xdisplay(), GET_QT_X_TIME());
+ XUngrabKeyboard(tqt_xdisplay(), get_tqt_x_time());
assert( forced_global_mouse_grab );
forced_global_mouse_grab = false;
if( active_client != NULL )
@@ -866,7 +866,7 @@ void Workspace::slotWalkThroughWindows()
if ( options->altTabStyle == Options::CDE || !options->focusPolicyIsReasonable())
{
- //XUngrabKeyboard(tqt_xdisplay(), GET_QT_X_TIME()); // need that because of accelerator raw mode
+ //XUngrabKeyboard(tqt_xdisplay(), get_tqt_x_time()); // need that because of accelerator raw mode
// CDE style raise / lower
CDEWalkThroughWindows( true );